==============
pydl Changelog
==============

0.4.1 (2015-09-22)
------------------

* No changes at all from 0.4.0.  This tag only exists because of a botched
  PyPI upload.

0.4.0 (2015-09-22)
------------------

* Use `astropy_helpers`_/v1.0.3, package-template_/v1.0.
* Remove some old FITS code that :mod:`astropy.io.fits` makes moot.
* Remove code for command-line scripts.  These are now auto-generated by the
  "entry_point" method.
* Remove Python/3.2 tests.
* Improved test coverage.
* Fixed problem with the :mod:`~pydl.pydlutils.spheregroup` code.
* Removed some code that is 100% redundant with astropy (*e.g.* ``angles_to_xyz()``).
* Fixed bug in :func:`~pydl.pydlutils.mangle.set_use_caps` that was discovered on the IDL side.
* Updated documentation of :func:`~pydl.pydlutils.mangle.read_fits_polygons`.
* Added cross-references to classes, functions, etc.

0.3.0 (2015-02-20)
------------------

* Use `astropy_helpers`_/v0.4.3, package-template_/v0.4.1.
* Avoided (but did not fix) a bug in :class:`~pydl.pydlutils.spheregroup.chunks` that occurs when operating on
  a list of coordinates of length 1.
* Fixed a typo in :class:`~pydl.pydlutils.bspline.bspline`, added documentation.
* Simplify documentation files.
* :func:`~pydl.pydlutils.sdss.sdss_flagname` now accepts more types of numeric input.
* Added :doc:`credits` file.

0.2.3 (2014-07-22)
------------------

* Added :mod:`pydl.photoop.window`.
* Added stub :func:`~pydl.photoop.sdssio.sdss_calib`, updated :func:`~pydl.photoop.window.sdss_score`.
* Added :func:`~pydl.photoop.photoobj.unwrap_objid`.
* Merged pull request #4, fixing some Python3 issues.

0.2.2 (2014-05-07)
------------------

* Updated to latest package-template_ version.
* Added ability to `write multiple ndarray to yanny files`_.
* Fixed :func:`~pydl.pydlutils.misc.struct_print` test for older Numpy versions.
* Fixed failing yanny file test.
* Improve test infrastructure, including Travis builds.
* Allow comment characters inside quoted strings in yanny files.

0.2.1 (2013-10-06)
------------------

* Added :func:`~pydl.pydlutils.sdss.sdss_sweep_circle`.
* Added first few :mod:`pydl.photoop` functions.
* Clean up some import statements.

0.2.0 (2013-04-22)
------------------

* Using the astropy package-template_ to bring pydl into astropy-compatible form.
* Some but not all tests are re-implemented.

0.1.1 (2013-03-06)
------------------

* Creating a tag representing the state immediately after creation of the
  `git repository`_.

0.1 (2010-11-10)
----------------

* Initial tag (made in svn, not visible in git).  Visible at
  http://www.sdss3.org/svn/repo/pydl/tags/0.1 .

.. _`astropy_helpers`: https://github.com/astropy/astropy-helpers
.. _package-template: https://github.com/astropy/package-template
.. _`git repository`: https://github.com/weaverba137/pydl
.. _`write multiple ndarray to yanny files`: https://github.com/weaverba137/pydl/pull/3
